<?php
/*
Plugin Name: Plugin Vulnerabilities
Plugin URI: https://www.pluginvulnerabilities.com/
Description: Alerts you when exploited vulnerabilities are in your installed plugins and provides access to our more comprehensive Plugin Vulnerabilities service.
Version: 2.0.90
Author: White Fir Design
Author URI: https://www.pluginvulnerabilities.com/
License: GPLv2
Text Domain: plugin-vulnerabilities
Domain Path: /languages

Copyright 2014-2024 White Fir Design

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; only version 2 of the License is applicable.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

//Block direct access to the file
if ( !function_exists( 'add_action' ) ) { 
	exit; 
}

if ( defined( 'WP_CLI' ) && WP_CLI ) {
  require_once 'wp-cli.php';
}

add_action( 'admin_init', 'plugin_vulnerabilities_admin_init' );
   
function plugin_vulnerabilities_admin_init() {
       wp_register_style( 'PluginVulnerabilitiesStylesheet', plugins_url('stylesheet.css', __FILE__) );
}

function plugin_vulnerabilities_admin_styles() {
       wp_enqueue_style( 'PluginVulnerabilitiesStylesheet' );
}
add_action( 'admin_print_styles-plugin-install.php', 'plugin_vulnerabilities_admin_styles' );

function plugin_vulnerabilities_init() {
	load_plugin_textdomain( 'plugin-vulnerabilities', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}
add_action('init', 'plugin_vulnerabilities_init');


function plugin_vulnerabilities_add_pages() {
	$page = add_plugins_page( 'Plugin Vulnerabilities', 'Plugin Vulnerabilities', 'manage_options', 'plugin-vulnerabilities', 'plugin_vulnerabilities_page'  );
}
add_action('admin_menu', 'plugin_vulnerabilities_add_pages');

add_action("after_plugin_row", 'plugin_vulnerabilities_add_plugin_row', 10, 3 );

function plugin_vulnerabilities_add_plugin_row ( $plugin_file, $plugin_data, $status ) {

	//Load vulnerabilities
	if (!isset($GLOBALS['plugin_vulnerabilities'])) {
		if (get_option('plugin_vulnerabilities_api_license_key') && get_option('plugin_vulnerabilities_vulnerability_data_cache') ) {
			$vulnerability_cache = get_option('plugin_vulnerabilities_vulnerability_data_cache');
			$GLOBALS['plugin_vulnerabilities'] = array();
			if ($vulnerability_cache != "None" ) {
				foreach ($vulnerability_cache as $vulnerability) {
					if ( !array_key_exists ($vulnerability["Path"],$GLOBALS['plugin_vulnerabilities']) )
						$GLOBALS['plugin_vulnerabilities'][$vulnerability["Path"]] =array();
					array_push($GLOBALS['plugin_vulnerabilities'][$vulnerability["Path"]], array(
							"FirstVersion" => esc_html($vulnerability["First Version"]),
							"LastVersion" => esc_html($vulnerability["Last Version"]),
							"TypeOfVulnerability" => esc_html($vulnerability["Type Of Vulnerability"]),
							"URL" => esc_url($vulnerability["URL"])
						)
					);
				}
			}				
		}
		if (get_option('plugin_vulnerabilities_possible_vulnerability_data_cache') ) {
			$vulnerability_cache = get_option('plugin_vulnerabilities_possible_vulnerability_data_cache');
			$GLOBALS['plugin_vulnerabilities_possible'] = array();
			if ($vulnerability_cache != "None" ) {
				foreach ($vulnerability_cache as $vulnerability) {
					if ( !array_key_exists ($vulnerability["Path"],$GLOBALS['plugin_vulnerabilities_possible']) )
						$GLOBALS['plugin_vulnerabilities_possible'][$vulnerability["Path"]] =array();
					array_push($GLOBALS['plugin_vulnerabilities_possible'][$vulnerability["Path"]], array(
							"Versions" => array_map("esc_html",$vulnerability["Versions"]),
							"ClaimedTypeOfVulnerability" => esc_html($vulnerability["Claimed Type Of Vulnerability"]),
							"URL" => esc_url($vulnerability["URL"])
						)
					);
				}
			}
		}
		/*else {
			$plugin_vulnerabilities;
			include_once('vulnerabilities.php');
			$GLOBALS['plugin_vulnerabilities'] = $plugin_vulnerabilities;
		}*/
	}

	//Check if installed plugins have vulnerabilities
	preg_match_all('/([a-z0-9\-\_]+)\//', $plugin_file, $plugin_path);
	if (isset($plugin_path[1][0])) {
		$plugin_path=$plugin_path[1][0];
		if ( !empty( $GLOBALS['plugin_vulnerabilities']) && array_key_exists($plugin_path, $GLOBALS['plugin_vulnerabilities'])) {
			$plugin = get_plugin_data( WP_PLUGIN_DIR."/".$plugin_file, $markup = true, $translate = true );
			foreach ($GLOBALS['plugin_vulnerabilities'][$plugin_path] as &$vulnerability) {
				if ( version_compare( $plugin["Version"], $vulnerability["FirstVersion"], '>=') && version_compare( $plugin["Version"], $vulnerability["LastVersion"], '<=') ) {
					//Handle a/an in message
					if ( preg_match( '/^[aeiou]/' , substr($vulnerability["TypeOfVulnerability"], 0, 1) ) ) {
						echo '<tr style="background-color: #FF8080;"><td colspan="4"><div>';
						echo sprintf(__('The %1$s plugin has an %2$s vulnerability.', 'plugin-vulnerabilities'), $plugin["Name"], '<a href="'.$vulnerability["URL"].'" target="_blank" rel="noopener noreferrer">'.$vulnerability["TypeOfVulnerability"].'</a>');
						echo '</div></td></tr>';	
					}
					else {
						echo '<tr style="background-color: #FF8080;"><td colspan="4"><div>';
						echo sprintf(__('The %1$s plugin has a %2$s vulnerability.', 'plugin-vulnerabilities'), $plugin["Name"], '<a href="'.$vulnerability["URL"].'" target="_blank" rel="noopener noreferrer">'.$vulnerability["TypeOfVulnerability"].'</a>');
						echo '</div></td></tr>';	
					}
				}
			}
		}
		if (!empty( $GLOBALS['plugin_vulnerabilities_possible']) && array_key_exists($plugin_path, $GLOBALS['plugin_vulnerabilities_possible'])) {
			$plugin = get_plugin_data( WP_PLUGIN_DIR."/".$plugin_file, $markup = true, $translate = true );
			foreach ($GLOBALS['plugin_vulnerabilities_possible'][$plugin_path] as &$vulnerability) {
				foreach ($vulnerability["Versions"] as $versions ){
					$version_array = explode("-", $versions);
					$first_version = $version_array[0];
					$last_version = $version_array[1];
					if ( version_compare( $plugin["Version"], $first_version, '>=') && version_compare( $plugin["Version"], $last_version, '<=') ) {
						//Handle a/an in message
						if ( preg_match( '/^[aeiou]/' , substr($vulnerability["ClaimedTypeOfVulnerability"], 0, 1) ) ) {
							echo '<tr style="background-color: #FFFF00;"><td colspan="4"><div>';
							echo sprintf(__('The %1$s plugin possibly contains an %2$s vulnerability. As this is commercial plugin we don\'t have access to all the versions of it to confirm if the vulnerability has existed and what versions are vulnerable. If you can provide us with a copy of the version you are using, we can check if its vulnerable and update our data set. Please get in touch with us at %3$s to do that.', 'plugin-vulnerabilities'), $plugin["Name"], '<a href="'.$vulnerability["URL"].'" target="_blank" rel="noopener noreferrer">'.$vulnerability["ClaimedTypeOfVulnerability"].'</a>', '<a href = "mailto:support@pluginvulnerabilities.com">support@pluginvulnerabilities.com</a>');
							echo '</div></td></tr>';	
						}
						else {
							echo '<tr style="background-color: #FFFF00;"><td colspan="4"><div>';
							echo sprintf(__('The %1$s plugin possibly contains a %2$s vulnerability. As this is commercial plugin we don\'t have access to all the versions of it to confirm if the vulnerability has existed and what versions are vulnerable. If you can provide us with a copy of the version you are using, we can check if its vulnerable and update our data set. Please get in touch with us at %3$s to do that.', 'plugin-vulnerabilities'), $plugin["Name"], '<a href="'.$vulnerability["URL"].'" target="_blank" rel="noopener noreferrer">'.$vulnerability["ClaimedTypeOfVulnerability"].'</a>', '<a href = "mailto:support@pluginvulnerabilities.com">support@pluginvulnerabilities.com</a>');
							echo '</div></td></tr>';	
						}
					}
				}
			}
		}
		include( 'developer-advisories.php' );
		if ( array_key_exists( $plugin_path, $developer_advisories ) ) {
			$plugin = get_plugin_data( WP_PLUGIN_DIR."/".$plugin_file, $markup = true, $translate = true );
			echo '<tr style="background-color: #FFFF00;"><td colspan="4"><div>';
			echo sprintf(__('The developer of the plugin %1$s is subject to an <a href="%2$s">advisory from Plugin Vulnerabilities</a> because of repeated security issues with their plugins.', 'plugin-vulnerabilities'), $plugin["Name"], esc_url($developer_advisories[$plugin_path]));
			echo '</div></td></tr>';	

		}
	}
}

function plugin_vulnerabilities_page() {

	//Store submitted data
	if ( ($_SERVER['REQUEST_METHOD'] === 'POST') && wp_verify_nonce($_POST['plugin_vulnerabilities'],'plugin_vulnerabilities') ) {
		if ( isset( $_POST['api-license-key'] ) && isset( $_POST['api-license-email'] ) ) {
		
			//clean up input
			while (substr($_POST['api-license-key'], 0, 1) === " ")
				 $_POST['api-license-key'] = substr_replace($_POST['api-license-key'],"",0,1);
			while (substr($_POST['api-license-key'], -1) === " ")
				 $_POST['api-license-key'] = substr_replace($_POST['api-license-key'],"",-1);
			while (substr($_POST['api-license-email'], 0, 1) === " ")
				 $_POST['api-license-email'] = substr_replace($_POST['api-license-email'],"",0,1);
			while (substr($_POST['api-license-email'], -1) === " ")
				 $_POST['api-license-email'] = substr_replace($_POST['api-license-email'],"",-1);
			$instance = trim( wp_generate_password( 12, false ) );
			$response = wp_remote_post( 'https://www.pluginvulnerabilities.com/?wc-api=am-software-api', array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking' => true,
				'headers' => array(),
				'body' => array( 'email' => $_POST['api-license-email'], 'licence_key' => $_POST['api-license-key'], 'request' => 'activation', 'product_id' => 'Subscription', 'instance' => $instance, 'platform' => get_site_url()),
				'cookies' => array()
    			)
			);
			if ( is_wp_error( $response ) )
				$activation_error = $response->get_error_message();
			else {
				$activation_response = json_decode($response["body"], true);
				if ( isset($activation_response['activated']) && $activation_response['activated'] == 'active' ) {
					update_option( 'plugin_vulnerabilities_api_license_key', $_POST['api-license-key'] );
					update_option( 'plugin_vulnerabilities_api_license_email', $_POST['api-license-email'] );
					update_option( 'plugin_vulnerabilities_api_license_instance', $instance );
					wp_clear_scheduled_hook( 'plugin_vulnerabilities_cron' );
					if (get_option('plugin_vulnerabilities_check_frequency') && ( get_option('plugin_vulnerabilities_check_frequency')=="hourly" || get_option('plugin_vulnerabilities_check_frequency')=="twicedaily" || get_option('plugin_vulnerabilities_check_frequency')=="daily" ) )
						wp_schedule_event( time(), get_option('plugin_vulnerabilities_check_frequency'), 'plugin_vulnerabilities_cron' );
					else 
						wp_schedule_event( time(), 'twicedaily', 'plugin_vulnerabilities_cron' );
				}
				else if ( isset($activation_response['error']) ) {
					$activation_error = $activation_response['error'];
				}
				else
					$activation_error = "Unknown Error";
			}
		}
		if ( isset( $_POST['deactivate'] ) ) {
			wp_remote_post( 'https://www.pluginvulnerabilities.com/?wc-api=am-software-api', array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking' => true,
				'headers' => array(),
				'body' => array( 'email' => get_option( 'plugin_vulnerabilities_api_license_email'), 'licence_key' => get_option( 'plugin_vulnerabilities_api_license_key'), 'request' => 'deactivation', 'product_id' => 'Subscription', 'instance' => get_option( 'plugin_vulnerabilities_api_license_instance'), 'platform' => get_site_url()),
				'cookies' => array()
    			)
			);
			delete_option( 'plugin_vulnerabilities_api_license_key');
			delete_option( 'plugin_vulnerabilities_api_license_email');
			delete_option( 'plugin_vulnerabilities_api_license_instance');
			if (!get_option('plugin_vulnerabilities_check_frequency') || ( get_option('plugin_vulnerabilities_check_frequency')!="hourly") ) {
				wp_clear_scheduled_hook( 'plugin_vulnerabilities_cron' );
				wp_schedule_event( time(), 'hourly', 'plugin_vulnerabilities_cron' );
			}
		}
		if ( isset( $_POST['email-address'] ) )
			update_option( 'plugin_vulnerabilities_email_address', $_POST['email-address'] );
		if ( isset( $_POST['check-frequency'] ) && ( $_POST['check-frequency']=="hourly" || $_POST['check-frequency']=="twicedaily" || $_POST['check-frequency']=="daily" ) ) {
			if ( ( get_option('plugin_vulnerabilities_check_frequency') && ( get_option('plugin_vulnerabilities_check_frequency')!= $_POST['check-frequency'] ) ) || ( !get_option('plugin_vulnerabilities_check_frequency') && $_POST['check-frequency'] != "twicedaily" ) ) {
				update_option( 'plugin_vulnerabilities_check_frequency', $_POST['check-frequency'] );
				wp_clear_scheduled_hook( 'plugin_vulnerabilities_cron' );
				wp_schedule_event( time(), get_option('plugin_vulnerabilities_check_frequency'), 'plugin_vulnerabilities_cron' );
			}
		}
		if ( isset( $_POST['automatic-updates'] ) && ( $_POST['automatic-updates']=="none" || $_POST['automatic-updates']=="low" || $_POST['automatic-updates']=="medium" || $_POST['automatic-updates']=="high" ) ) {
				update_option( 'plugin_vulnerabilities_automatic_updates', $_POST['automatic-updates'] );
		}
	}

	wp_enqueue_script('plugin-install');
	add_thickbox();

	if (get_option('plugin_vulnerabilities_api_license_key'))
		include( 'advanced.php' );
	else 
		include( 'basic.php' );
}

//Handle activation
register_activation_hook( __FILE__, 'plugin_vulnerabilities_activation' );
function plugin_vulnerabilities_activation() {
	if (get_option('plugin_vulnerabilities_api_license_key')) {
		if (get_option('plugin_vulnerabilities_check_frequency') && ( get_option('plugin_vulnerabilities_check_frequency')=="hourly" || get_option('plugin_vulnerabilities_check_frequency')=="twicedaily" || get_option('plugin_vulnerabilities_check_frequency')=="daily" ) )
			wp_schedule_event( time(), get_option('plugin_vulnerabilities_check_frequency'), 'plugin_vulnerabilities_cron' );
		else 
			wp_schedule_event( time(), 'twicedaily', 'plugin_vulnerabilities_cron' );
	}
	else
		wp_schedule_event( time(), 'hourly', 'plugin_vulnerabilities_cron' );
}


//Cron
add_action( 'plugin_vulnerabilities_cron', 'plugin_vulnerabilities_cron' );

function plugin_vulnerabilities_cron() {

	if (get_option('plugin_vulnerabilities_api_license_key'))
		plugin_vulnerabilities_advanced_cron();
	else
		plugin_vulnerabilities_basic_cron();
}

function plugin_vulnerabilities_advanced_cron() {
	//Load previously alerted vulnerabilities
	if (get_option('plugin_vulnerabilities_email_alerts_sent'))
		$email_alerts_sent = get_option('plugin_vulnerabilities_email_alerts_sent');
	else
		$email_alerts_sent = array();
	if (get_option('plugin_vulnerabilities_possible_email_alerts_sent'))
		$possible_email_alerts_sent = get_option('plugin_vulnerabilities_possible_email_alerts_sent');
	else
		$possible_email_alerts_sent = array();
	if (get_option('plugin_vulnerabilities_developer_advisory_email_alerts_sent'))
		$developer_advisory_email_alerts_sent = get_option('plugin_vulnerabilities_developer_advisory_email_alerts_sent');
	else
		$developer_advisory_email_alerts_sent = array();
		
	$installed_plugins = plugin_vulnerabilities_gather_plugins();
	$plugin_api_data = plugin_vulnerabilities_prepare_plugin_data_for_api_request($installed_plugins);
	if ( count($installed_plugins) > 110 ) {
		$subject = sprintf(__('[%s] Plugin Vulnerabilities Could Not Run', 'plugin-vulnerabilities'), get_option( 'blogname' ));
		$message = sprintf(__('WordPress site: %s', 'plugin-vulnerabilities'),get_option( 'siteurl' ));
		$message .= "\n\n";
		$message .= sprintf(__('The Plugin Vulnerabilities service only currently handles checking 110 plugins at a time and you have %d installed. Please let us know that we need to increase the number of plugins that can be checked by contacting us at support@pluginvulnerabilities.com.','plugin-vulnerabilities'), count($installed_plugins));
		if ( get_option( 'plugin_vulnerabilities_email_address' ) )
			wp_mail( get_option( 'plugin_vulnerabilities_email_address' ), $subject, $message);
		else
			wp_mail( get_option( 'admin_email' ), $subject, $message);
	}
	else {
		$results = plugin_vulnerabilities_send_request ('current', $plugin_api_data);
		
		if ($results["Status"] == "API license key is active.") {
			update_option('plugin_vulnerabilities_vulnerability_data_cache',$results["Vulnerabilites"]);
			update_option('plugin_vulnerabilities_possible_vulnerability_data_cache',$results["Possible Vulnerabilites"]);
			if ($results["Vulnerabilites"] != "None" ) {
				foreach ($results["Vulnerabilites"] as $vulnerability) {
					$name = $installed_plugins[$vulnerability["Path"]]["Name"];
					if ( (array_key_exists($name, $email_alerts_sent) && (!in_array($vulnerability["URL"], $email_alerts_sent[$name]))) || !array_key_exists($name, $email_alerts_sent) ) {
						$version = $installed_plugins[$vulnerability["Path"]]["Version"];
						$typeOfVulnerability = esc_html($vulnerability["Type Of Vulnerability"]);
						$likelihoodOfExploitation = esc_html($vulnerability["Likelihood Of Exploitation"]);
						$vulnerabilityURL = esc_url($vulnerability["URL"]);
			
						$subject = sprintf(__('[%1$s] Vulnerability in Installed Version of %2$s', 'plugin-vulnerabilities'),get_option( 'blogname' ),$name);
						$message = sprintf(__('WordPress site: %s','plugin-vulnerabilities'), get_option( 'siteurl' ));
						$message .= "\n\n";
						//Handle a/an in message
						if ( preg_match( '/^[aeiou]/' , substr($typeOfVulnerability, 0, 1) ) )
							$message .= sprintf(__('The installed version of the %1$s plugin, %2$s, contains an %3$s vulnerability. We estimate the likelihood of the vulnerability being exploited to be %4$s. More details on the vulnerability can be found at %5$s.', 'plugin-vulnerabilities'), $name, $version, $typeOfVulnerability, $likelihoodOfExploitation, $vulnerabilityURL);
						else
							$message .= sprintf(__('The installed version of the %1$s plugin, %2$s, contains a %3$s vulnerability. We estimate the likelihood of the vulnerability being exploited to be %4$s. More details on the vulnerability can be found at %5$s.', 'plugin-vulnerabilities'), $name, $version, $typeOfVulnerability, $likelihoodOfExploitation, $vulnerabilityURL);
						$message .= "\n\n";
						$message .= __('If you have any questions about dealing with this vulnerability please get in touch with us at support@pluginvulnerabilities.com.', 'plugin-vulnerabilities');
						$message .= "\n\n\n";
						$message .= __('Warning sent from the Plugin Vulnerabilities plugin.', 'plugin-vulnerabilities');
						if ( get_option( 'plugin_vulnerabilities_email_address' ) ) {
							if ( get_option( 'plugin_vulnerabilities_email_address' ) != "disabled" )
								wp_mail( get_option( 'plugin_vulnerabilities_email_address' ), $subject, $message);
						}
						else
							wp_mail( get_option( 'admin_email' ), $subject, $message);
			
						if (!array_key_exists($name, $email_alerts_sent)) {
							$email_alerts_sent[$name] = array($vulnerability["URL"]);
						}
						else
							array_push($email_alerts_sent[$name], $vulnerability["URL"]);
						update_option('plugin_vulnerabilities_email_alerts_sent',$email_alerts_sent);
					}
				}
			}
			if ($results["Possible Vulnerabilites"] != "None" ) {
				foreach ($results["Possible Vulnerabilites"] as $possiblevulnerability) {
					$name = $installed_plugins[$possiblevulnerability["Path"]]["Name"];
					if ( (array_key_exists($name, $possible_email_alerts_sent) && (!in_array($possiblevulnerability["URL"], $possible_email_alerts_sent[$name]))) || !array_key_exists($name, $possible_email_alerts_sent) ) {
						$version = $installed_plugins[$possiblevulnerability["Path"]]["Version"];
						$typeOfVulnerability = esc_html($possiblevulnerability["Claimed Type Of Vulnerability"]);
						$vulnerabilityURL = esc_url($possiblevulnerability["URL"]);
			
						$subject = sprintf(__('[%1$s] Possible Vulnerability in Installed Version of %2$s', 'plugin-vulnerabilities'),get_option( 'blogname' ),$name);
						$message = sprintf(__('WordPress site: %s','plugin-vulnerabilities'), get_option( 'siteurl' ));
						$message .= "\n\n";
						//Handle a/an in message
						if ( preg_match( '/^[aeiou]/' , substr($typeOfVulnerability, 0, 1) ) )
							$message .= sprintf(__('The installed version of the %1$s plugin, %2$s, possibly contains an %3$s vulnerability. As this is commercial plugin we don\'t have access to all the versions of it to confirm if the vulnerability has existed and what versions are vulnerable. If you can provide us with a copy of the version you are using, we can check if its vulnerable and update our data set. Please get in touch with us at support@pluginvulnerabilities.com to do that.', 'plugin-vulnerabilities'), $name, $version, $typeOfVulnerability);
						else
							$message .= sprintf(__('The installed version of the %1$s plugin, %2$s, possibly contains a %3$s vulnerability. As this is commercial plugin we don\'t have access to all the versions of it to confirm if the vulnerability has existed and what versions are vulnerable. If you can provide us with a copy of the version you are using, we can check if its vulnerable and update our data set. Please get in touch with us at support@pluginvulnerabilities.com to do that.', 'plugin-vulnerabilities'), $name, $version, $typeOfVulnerability);
						$message .= "\n\n";
						$message .= sprintf(__('More details on the possible vulnerability can be found at %1$s.', 'plugin-vulnerabilities'), $vulnerabilityURL);
						$message .= "\n\n\n";
						$message .= __('Warning sent from the Plugin Vulnerabilities plugin.', 'plugin-vulnerabilities');
						if ( get_option( 'plugin_vulnerabilities_email_address' ) ) {
							if ( get_option( 'plugin_vulnerabilities_email_address' ) != "disabled" )
								wp_mail( get_option( 'plugin_vulnerabilities_email_address' ), $subject, $message);
						}
						else
							wp_mail( get_option( 'admin_email' ), $subject, $message);
			
						if (!array_key_exists($name, $possible_email_alerts_sent)) {
							$possible_email_alerts_sent[$name] = array($possiblevulnerability["URL"]);
						}
						else
							array_push($possible_email_alerts_sent[$name], $possiblevulnerability["URL"]);
						update_option('plugin_vulnerabilities_possible_email_alerts_sent',$possible_email_alerts_sent);
					}
				}
				
			//Load developer advisories
			include( 'developer-advisories.php' );

			//Check if installed plugins have developer advisories
			foreach ($installed_plugins as $slug => $data) {

					if ( array_key_exists($slug, $developer_advisories) && ( !array_key_exists( $slug, $developer_advisory_email_alerts_sent ) || !in_array( $developer_advisories[$slug], $developer_advisory_email_alerts_sent[$slug] ) ) ) {
					$name = $installed_plugins[$slug]["Name"];
	
					$advisoryURL = esc_url($possiblevulnerability["URL"]);
		
					$subject = sprintf(__('[%1$s] Developer Security Advisory for %2$s', 'plugin-vulnerabilities'),get_option( 'blogname' ),$name);
					$message = sprintf(__('WordPress site: %s','plugin-vulnerabilities'), get_option( 'siteurl' ));
					$message .= "\n\n";
					$message .= sprintf(__('The developer of the %1$s plugin is the subject of a security advisory from Plugin Vulnerabilities.', 'plugin-vulnerabilities'), $name);
					$message .= "\n\n";
					$message .= sprintf(__('Details on the advisory can be found at %1$s.', 'plugin-vulnerabilities'), $advisoryURL);
						$message .= "\n\n";
						$message .= __('If you have any questions about this advisory please get in touch with us at support@pluginvulnerabilities.com.', 'plugin-vulnerabilities');
					$message .= "\n\n\n";
					$message .= __('Warning sent from the Plugin Vulnerabilities plugin.', 'plugin-vulnerabilities');
					if ( get_option( 'plugin_vulnerabilities_email_address' ) ) {
						if ( get_option( 'plugin_vulnerabilities_email_address' ) != "disabled" )
							wp_mail( get_option( 'plugin_vulnerabilities_email_address' ), $subject, $message);
					}
					else
						wp_mail( get_option( 'admin_email' ), $subject, $message);
		
					if (!array_key_exists($slug, $developer_advisory_email_alerts_sent)) {
						$developer_advisory_email_alerts_sent[$slug] = array($developer_advisories[$slug]);
					}
					else
						array_push($developer_advisory_email_alerts_sent[$slug], $developer_advisories[$slug]);
					update_option('plugin_vulnerabilities_developer_advisory_email_alerts_sent',$developer_advisory_email_alerts_sent);
				}
			}
				
				//Handle automatic updates
				if ( get_option('plugin_vulnerabilities_automatic_updates') && ( get_option('plugin_vulnerabilities_automatic_updates')=='low' || get_option('plugin_vulnerabilities_automatic_updates')=='medium' || get_option('plugin_vulnerabilities_automatic_updates')=='high') ) {
					$likelihood = plugin_vulnerabilities_likelihood_integer(get_option( 'plugin_vulnerabilities_automatic_updates' ) );
					$update_plugins = array();
					$update_check_scheduled = false;
					$crontime = time() + 300;
					foreach ($results["Vulnerabilites"] as $vulnerability) {
						if ( $vulnerability["Update Available"] == "yes" && !in_array($vulnerability["Path"], $update_plugins) && ( plugin_vulnerabilities_likelihood_integer($vulnerability["Likelihood Of Exploitation"]) >= $likelihood ) ) {
							$update_plugins[] = $vulnerability["Path"];
							if (!$update_check_scheduled ) {
								wp_schedule_single_event( $crontime, 'plugin_vulnerabilities_advanced_cron_update_check' );
								$update_check_scheduled  = true;
							}
							$plugin_path = $vulnerability["Path"];
							$plugin_data = get_plugins("/".$plugin_path);
							$plugin_file = array_keys($plugin_data)[0];
							$crontime = $crontime + 300;
							wp_schedule_single_event( $crontime, 'plugin_vulnerabilities_advanced_cron_update_plugin', array( $plugin_path.'/'.$plugin_file, $installed_plugins[$vulnerability["Path"]]["Name"] ) );
						}
					}
				}
			}
		}
	}
}

function plugin_vulnerabilities_advanced_cron_update_check() {
	wp_update_plugins('force check');
}
add_action( 'plugin_vulnerabilities_advanced_cron_update_check' , 'plugin_vulnerabilities_advanced_cron_update_check' );

function plugin_vulnerabilities_advanced_cron_update_plugin( $path, $name) {
	$update_plugins_data = get_site_transient( 'update_plugins' );
	if ( isset( $update_plugins_data->response[ $path ] ) ) {
		$response = $update_plugins_data->response[ $path ];
		global $wp_version;
		//is_php_version_compatible() and is_wp_version_compatible() added in that version 
		if ( version_compare( $wp_version, '5.2', '>=' ) ) {
			$requires_php   = isset( $response->requires_php ) ? $response->requires_php : null;
			$do_upgrade = is_php_version_compatible( $requires_php);
			
			if ($do_upgrade) {
				$requires_wordpress   = isset( $response->requires ) ? $response->requires : null;
				$do_upgrade = is_wp_version_compatible( $requires_wordpress);
			}
		}
		else
			$do_upgrade = true;
		if ( $do_upgrade) {
			include_once ABSPATH . 'wp-admin/includes/misc.php';
			include_once ABSPATH . 'wp-admin/includes/file.php';
			include_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
			set_time_limit( 300 );
			$upgrader = new Plugin_Upgrader();
			if ( $upgrader->upgrade( $path ) ) {
				$subject = sprintf(__('[%s] Plugin Vulnerabilities Has Updated %s', 'plugin-vulnerabilities'), get_option( 'blogname' ), $name);
				$message = sprintf(__('WordPress site: %s', 'plugin-vulnerabilities'),get_option( 'siteurl' ));
				$message .= "\n\n";
				$message .= sprintf(__('The Plugin Vulnerabilities plugin has updated the plugin %s to version %s to fix a vulnerability or vulnerabilities.','plugin-vulnerabilities'), $name, $response->new_version);
			}
			else {
				$subject = sprintf(__('[%s] Plugin Vulnerabilities Failed to Update %s', 'plugin-vulnerabilities'), get_option( 'blogname' ), $name);
				$message = sprintf(__('WordPress site: %s', 'plugin-vulnerabilities'),get_option( 'siteurl' ));
				$message .= "\n\n";
				$message .= sprintf(__('The Plugin Vulnerabilities plugin has failed to update the plugin %s to version %s to fix a vulnerability or vulnerabilities.','plugin-vulnerabilities'), $name, $response->new_version);
			}
			if ( get_option( 'plugin_vulnerabilities_email_address' ) )
				wp_mail( get_option( 'plugin_vulnerabilities_email_address' ), $subject, $message);
			else
				wp_mail( get_option( 'admin_email' ), $subject, $message);
		}
	}
}
add_action( 'plugin_vulnerabilities_advanced_cron_update_plugin' , 'plugin_vulnerabilities_advanced_cron_update_plugin', 10, 2 );

function plugin_vulnerabilities_likelihood_integer($likelihood) {
	switch ( $likelihood ) {
		case 'low':
			return 1;
			break;
		case 'medium':
			return 2;
			break;
		case 'high':
			return 3;
			break;
	}
}

function plugin_vulnerabilities_basic_cron() {
	if ( ! function_exists( 'get_plugins' ) )
        require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
    $plugin_folder = get_plugins( '/' . plugin_basename( dirname( __FILE__ ) ) );
    $plugin_file = basename( ( __FILE__ ) );

	if ( ( get_option('plugin_vulnerabilities_version') && version_compare( get_option('plugin_vulnerabilities_version'),$plugin_folder[$plugin_file]['Version'],'<') ) || (!get_option('plugin_vulnerabilities_version')) ) {
	
		/*
		//Load vulnerabilities
		$plugin_vulnerabilities;
			include_once('vulnerabilities.php');
		
		//Load previously alerted vulnerabilities
		if (get_option('plugin_vulnerabilities_email_alerts_sent'))
			$email_alerts_sent = get_option('plugin_vulnerabilities_email_alerts_sent');
		else
			$email_alerts_sent = array();
		
		//Check if installed plugins have vulnerabilities
		$plugin_list = get_plugins();
		$plugin_list_paths = array_keys($plugin_list);
		$current = "";
		$old = "";
		foreach ($plugin_list_paths as &$value) {
			preg_match_all('/([a-z0-9\-\_]+)\//', $value, $plugin_path);
			if (isset($plugin_path[1][0])) {
				$plugin_path=$plugin_path[1][0];
			
				if (array_key_exists($plugin_path, $plugin_vulnerabilities)) {
					$plugin = get_plugin_data( WP_PLUGIN_DIR."/".$value, $markup = true, $translate = true );
					foreach ($plugin_vulnerabilities[$plugin_path] as &$vulnerability) {
						if ( version_compare( $plugin["Version"], $vulnerability["FirstVersion"], '>=') && version_compare( $plugin["Version"], $vulnerability["LastVersion"], '<=') ) {
							if ( (array_key_exists($plugin["Name"], $email_alerts_sent) && (!in_array($vulnerability["URL"], $email_alerts_sent[$plugin["Name"]]))) || !array_key_exists($plugin["Name"], $email_alerts_sent) ) {
								$name = $plugin["Name"];
								$version = $plugin["Version"];
								$vulnerability = $vulnerability["TypeOfVulnerability"];
								$vulnerabilityURL = $vulnerability["URL"];
								
								$subject = sprintf(__('[%1$s] Vulnerability in Installed Version of %2$s', 'plugin-vulnerabilities'),get_option( 'blogname' ),$name);
								$message = sprintf(__('WordPress site: %s','plugin-vulnerabilities'), get_option( 'siteurl' ));
								$message .= "\n\n";
								//Handle a/an in message
								if ( preg_match( '/^[aeiou]/' , substr($vulnerability, 0, 1) ) )
									$message .= sprintf(__('The installed version of the %1$s plugin, %2$s, contains an %3$s vulnerability. More details on the vulnerability can be found at %4$s.', 'plugin-vulnerabilities'), $name, $version, $vulnerability, $vulnerabilityURL);
								else
									$message .= sprintf(__('The installed version of the %1$s plugin, %2$s, contains a %3$s vulnerability. More details on the vulnerability can be found at %4$s.', 'plugin-vulnerabilities'), $name, $version, $vulnerability, $vulnerabilityURL);
								$message .= "\n\n";
								$message .= __('You can get alerted for known vulnerabilities in all of the plugins you use, not just ones that we have seen evidence that hackers are targeting, when you sign up for our Plugin Vulnerabilities service: https://www.pluginvulnerabilities.com/', 'plugin-vulnerabilities');
								$message .= "\n\n";
								$message .= __('As the data for that service comes from checking with our service\'s API, you don\'t need to update the plugin to get alerted to new issues and you can have checks done as often as hourly.', 'plugin-vulnerabilities');
								$message .= "\n\n\n";
								$message .= __('Currently our service warns about vulnerabilities in the most recent version of plugins with over one million active installs that are still available in the Plugin Directory.', 'plugin-vulnerabilities');
								$message .= "\n\n\n";
								$message .= __('Through the service you also have access to a number of other important features including the ability to suggest/vote for which plugins we will do security reviews of and help when dealing with a situation where you are using a plugin where the vulnerability has yet to be fixed (we can usually provide a temporary fix for the issue).', 'plugin-vulnerabilities');
								$message .= "\n\n\n";
								$message .= __('You can currently sign up for half off when you use the coupon code "HalfOff" when signing up.', 'plugin-vulnerabilities');
								$message .= "\n\n\n";
								$message .= __('Warning sent from the Plugin Vulnerabilities plugin.', 'plugin-vulnerabilities');

								wp_mail( get_option( 'admin_email' ), $subject, $message);
								
								if (!array_key_exists($plugin["Name"], $email_alerts_sent)) {
									$email_alerts_sent[$plugin["Name"]] = array($vulnerability["URL"]);
								}
								else
									array_push($email_alerts_sent[$plugin["Name"]], $vulnerability["URL"]);
								update_option('plugin_vulnerabilities_email_alerts_sent',$email_alerts_sent);
							}
						}
					}
				}
			}
		}*/
		
		//Load previous email alerts
		if (get_option('plugin_vulnerabilities_developer_advisory_email_alerts_sent'))
			$developer_advisory_email_alerts_sent = get_option('plugin_vulnerabilities_developer_advisory_email_alerts_sent');
		else
			$developer_advisory_email_alerts_sent = array();
		
		//Get installed plugins
		$installed_plugins = plugin_vulnerabilities_gather_plugins();
		
		//Load developer advisories
		include( 'developer-advisories.php' );

		//Check if installed plugins have developer advisories
		foreach ($installed_plugins as $slug => $data) {

				if ( array_key_exists($slug, $developer_advisories) && ( !array_key_exists( $slug, $developer_advisory_email_alerts_sent ) || !in_array( $developer_advisories[$slug], $developer_advisory_email_alerts_sent[$slug] ) ) ) {
				$name = $installed_plugins[$slug]["Name"];

				$advisoryURL = esc_url($possiblevulnerability["URL"]);
	
				$subject = sprintf(__('[%1$s] Developer Security Advisory for %2$s', 'plugin-vulnerabilities'),get_option( 'blogname' ),$name);
				$message = sprintf(__('WordPress site: %s','plugin-vulnerabilities'), get_option( 'siteurl' ));
				$message .= "\n\n";
				$message .= sprintf(__('The developer of the %1$s plugin is the subject of a security advisory from Plugin Vulnerabilities.', 'plugin-vulnerabilities'), $name);
				$message .= "\n\n";
				$message .= sprintf(__('Details on the advisory can be found at %1$s.', 'plugin-vulnerabilities'), $advisoryURL);
					$message .= "\n\n";
					$message .= __('If you have any questions about this advisory please get in touch with us at support@pluginvulnerabilities.com.', 'plugin-vulnerabilities');
				$message .= "\n\n\n";
				$message .= __('Warning sent from the Plugin Vulnerabilities plugin.', 'plugin-vulnerabilities');
				if ( get_option( 'plugin_vulnerabilities_email_address' ) ) {
					if ( get_option( 'plugin_vulnerabilities_email_address' ) != "disabled" )
						wp_mail( get_option( 'plugin_vulnerabilities_email_address' ), $subject, $message);
				}
				else
					wp_mail( get_option( 'admin_email' ), $subject, $message);
	
				if (!array_key_exists($slug, $developer_advisory_email_alerts_sent)) {
					$developer_advisory_email_alerts_sent[$slug] = array($developer_advisories[$slug]);
				}
				else
					array_push($developer_advisory_email_alerts_sent[$slug], $developer_advisories[$slug]);
				update_option('plugin_vulnerabilities_developer_advisory_email_alerts_sent',$developer_advisory_email_alerts_sent);
			}
		}
		update_option('plugin_vulnerabilities_version',$plugin_folder[$plugin_file]['Version']);
	}
}

register_deactivation_hook( __FILE__, 'plugin_vulnerabilities_deactivation' );
function plugin_vulnerabilities_deactivation() {
	wp_clear_scheduled_hook( 'plugin_vulnerabilities_cron' );
}

function plugin_vulnerabilities_gather_plugins () {
	if ( ! function_exists( 'get_plugins' ) )
        require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
        
	$installed_plugins = array();
	$plugin_list = get_plugins();
	$plugin_list_paths = array_keys($plugin_list);

	foreach ($plugin_list_paths as &$value) {
		preg_match_all('/([a-z0-9\-\_]+)\//', $value, $plugin_path);
		if (isset($plugin_path[1][0])) {
			$plugin_path=$plugin_path[1][0];
			$plugin = get_plugin_data( WP_PLUGIN_DIR."/".$value, $markup = true, $translate = true );
			$installed_plugins[$plugin_path] = array ("Name" => $plugin["Name"],
													  "Version" => $plugin["Version"]
																   );
		}
	}
	return $installed_plugins;
}

function plugin_vulnerabilities_prepare_plugin_data_for_api_request ($plugins) {
	$pluging_api_data = array();
	foreach ($plugins as $name => $plugin_data) {
		$pluging_api_data[$name] = $plugin_data["Version"];
	}
	return $pluging_api_data;
}

function plugin_vulnerabilities_send_request ($request_type, $plugins) {
	$response = wp_remote_post( 'https://www.pluginvulnerabilities.com/api/', array(
	'method' => 'POST',
	'timeout' => 45,
	'redirection' => 5,
	'httpversion' => '1.0',
	'blocking' => true,
	'headers' => array(),
	'body' => array( 'site-url' => get_site_url(), 'api-license-key' => get_option('plugin_vulnerabilities_api_license_key'), 'api-license-email' => get_option('plugin_vulnerabilities_api_license_email'), 'api-license-instance' => get_option('plugin_vulnerabilities_api_license_instance'), 'request-type' => $request_type, 'plugins' => json_encode($plugins) ),
	'cookies' => array()
    )
);
	if ( is_wp_error( $response ) )
		return array ("Status" => "Could not connect.",
					  "Error" => $response->get_error_message()
					);
	else
		return json_decode($response["body"], true);
}

//Changes Plugin Details Page
function plugin_vulnerabilities_developer_advisory ( $res, $action, $args ) {
	if ( $action = "plugin_information" && isset ($res->sections['description']) ) {
		//Developer Advisories
		include_once( 'developer-advisories.php' );
		if ( array_key_exists($res->slug, $developer_advisories) )
			$res->sections['description']='<div class="notice notice-warning notice-alt"><p><strong>Warning:</strong> The developer of this plugin is the subject of a <a href="'.$developer_advisories[$res->slug].'" target="blank">security advisory</a> by Plugin Vulnerabilities.</p></div>'.$res->sections['description'];
		
		//Vulnerabilites Page
		$vulnerabilities = "";
		if (get_option('plugin_vulnerabilities_api_license_key')) {
			$plugin_api_data = array();
			$plugin_api_data[$res->slug]="";
			$results = plugin_vulnerabilities_send_request ('single', $plugin_api_data);
			if ($results["Status"] == "API license key is active." && $results["Vulnerabilites"] != "None") {
				$vulnerabilities .= '<ul>';
				foreach ($results["Vulnerabilites"] as $vulnerability) {
					//Add new Entry to Vulnerabilities Tab
					$vulnerabilities .= '<li>';
					$vulnerabilities .= '<a href="'.esc_url( $vulnerability["URL"]).'" target="_blank" rel="noopener noreferrer">'.ucfirst(esc_attr($vulnerability["Type Of Vulnerability"])).' vulnerability</a>';
					$vulnerabilities .= ' in versions ';
					$vulnerabilities .= esc_html($vulnerability["First Version"]).'-'.esc_html($vulnerability["Last Version"]);
					$vulnerabilities .= '</li>';
					//Show Warning on Description Page
					if ( version_compare( $res->version, $vulnerability["First Version"], '>=') && version_compare( $res->version, $vulnerability["Last Version"], '<=') ) {
						//Handle a/an in message
						if ( preg_match( '/^[aeiou]/' , substr($vulnerability["Type Of Vulnerability"], 0, 1) ) )
							$message = sprintf(__('The current version of this plugin contains an %1$s vulnerability. More details on the vulnerability can be found %2$shere%3$s.', 'plugin-vulnerabilities'), esc_html($vulnerability["Type Of Vulnerability"]), '<a href="'.esc_url( $vulnerability["URL"]).'" target="_blank" rel="noopener noreferrer">','</a>');
						else
							$message = sprintf(__('The current version of this plugin contains a %1$s vulnerability. More details on the vulnerability can be found %2$shere%3$s.', 'plugin-vulnerabilities'), esc_html($vulnerability["Type Of Vulnerability"]), '<a href="'.esc_url( $vulnerability["URL"]).'" target="_blank" rel="noopener noreferrer">','</a>');
						$res->sections['description']='<div class="notice notice-warning notice-alt plugin_vulnerabilities_current_version"><p><strong>Warning:</strong> '.$message.'</p></div>'.$res->sections['description'];
					}
				}
				$vulnerabilities .= '</ul>';
				$res->sections['vulnerabilities'] = $vulnerabilities;	
			}
		}
		else {
			$plugin_vulnerabilities;
			include_once('vulnerabilities.php');
			if ( array_key_exists($res->slug, $plugin_vulnerabilities) ) {
				$vulnerabilities .= '<ul>';
				foreach ($plugin_vulnerabilities[$res->slug] as &$vulnerability) {
					//Add new Entry to Vulnerabilities Tab
					$vulnerabilities .= '<li>';
					$vulnerabilities .= '<a href="'.$vulnerability["URL"].'" target="_blank" rel="noopener noreferrer">'.ucfirst($vulnerability["TypeOfVulnerability"]).' vulnerability</a>';
					$vulnerabilities .= ' in versions ';
					$vulnerabilities .= $vulnerability["FirstVersion"].'-'.$vulnerability["LastVersion"];
					$vulnerabilities .= '</li>';
					//Show Warning on Description Page
					if ( version_compare( $res->version, $vulnerability["FirstVersion"], '>=') && version_compare( $res->version, $vulnerability["LastVersion"], '<=') ) {
						//Handle a/an in message
						if ( preg_match( '/^[aeiou]/' , substr($vulnerability["TypeOfVulnerability"], 0, 1) ) )
							$message = sprintf(__('The current version of this plugin contains an %1$s vulnerability. More details on the vulnerability can be found %2$shere%3$s.', 'plugin-vulnerabilities'), $vulnerability["TypeOfVulnerability"], '<a href="'.$vulnerability["URL"].'" target="_blank" rel="noopener noreferrer">','</a>');
						else
							$message = sprintf(__('The current version of this plugin contains a %1$s vulnerability. More details on the vulnerability can be found %2$shere%3$s.', 'plugin-vulnerabilities'), $vulnerability["TypeOfVulnerability"], '<a href="'.$vulnerability["URL"].'" target="_blank" rel="noopener noreferrer">','</a>');
						$res->sections['description']='<div class="notice notice-warning notice-alt plugin_vulnerabilities_current_version"><p><strong>Warning:</strong> '.$message.'</p></div>'.$res->sections['description'];
					}
				}
				$vulnerabilities .= '</ul>';
				$res->sections['vulnerabilities'] = $vulnerabilities;	
			}
		}
	}

	return $res;
}
add_filter ( 'plugins_api_result', 'plugin_vulnerabilities_developer_advisory', 10, 3);

//https://github.com/rudrastyh/misha-update-checker/blob/main/misha-update-checker.php
class pv_mishaUpdateChecker{

	public $plugin_slug;
	public $version;
	public $cache_key;
	public $cache_allowed;

	public function __construct() {

		$this->plugin_slug = plugin_basename( __DIR__ );
		$this->version = '2.0.90';
		$this->cache_key = 'plugin_vulnerabilities_custom_upd';
		$this->cache_allowed = true;

		add_filter( 'plugins_api', array( $this, 'info' ), 20, 3 );
		add_filter( 'site_transient_update_plugins', array( $this, 'update' ) );
		add_action( 'upgrader_process_complete', array( $this, 'purge' ), 10, 2 );

	}

	public function request(){

		$remote = get_transient( $this->cache_key );

		if( false === $remote || ! $this->cache_allowed ) {

			$remote = wp_remote_get(
				'https://www.pluginvulnerabilities.com/update/plugin-vulnerabilities.json',
				array(
					'timeout' => 10,
					'headers' => array(
						'Accept' => 'application/json'
					)
				)
			);

			if(
				is_wp_error( $remote )
				|| 200 !== wp_remote_retrieve_response_code( $remote )
				|| empty( wp_remote_retrieve_body( $remote ) )
			) {
				return false;
			}

			set_transient( $this->cache_key, $remote, DAY_IN_SECONDS );

		}

		$remote = json_decode( wp_remote_retrieve_body( $remote ) );

		return $remote;

	}


	function info( $res, $action, $args ) {

		// do nothing if you're not getting plugin information right now
		if( 'plugin_information' !== $action ) {
			return false;
		}

		// do nothing if it is not our plugin
		if( $this->plugin_slug !== $args->slug ) {
			return false;
		}

		// get updates
		$remote = $this->request();

		if( ! $remote ) {
			return false;
		}

		$res = new stdClass();

		$res->name = $remote->name;
		$res->slug = $remote->slug;
		$res->version = $remote->version;
		$res->tested = $remote->tested;
		$res->requires = $remote->requires;
		$res->author = $remote->author;
		$res->author_profile = $remote->author_profile;
		$res->download_link = $remote->download_url;
		$res->trunk = $remote->download_url;
		$res->requires_php = $remote->requires_php;
		$res->last_updated = $remote->last_updated;

		$res->sections = array(
			'description' => $remote->sections->description,
			'installation' => $remote->sections->installation,
			'changelog' => $remote->sections->changelog
		);

		if( ! empty( $remote->banners ) ) {
			$res->banners = array(
				'low' => $remote->banners->low,
				'high' => $remote->banners->high
			);
		}

		return $res;

	}

	public function update( $transient ) {

		if ( empty($transient->checked ) ) {
			return $transient;
		}

		$remote = $this->request();

		if(
			$remote
			&& version_compare( $this->version, $remote->version, '<' )
			&& version_compare( $remote->requires, get_bloginfo( 'version' ), '<' )
			&& version_compare( $remote->requires_php, PHP_VERSION, '<' )
		) {
			$res = new stdClass();
			$res->slug = $this->plugin_slug;
			$res->plugin = plugin_basename( __FILE__ );
			$res->new_version = $remote->version;
			$res->tested = $remote->tested;
			$res->package = $remote->download_url;

			$transient->response[ $res->plugin ] = $res;

	}

		return $transient;

	}

	public function purge( $upgrader, $options ){

		if (
			$this->cache_allowed
			&& 'update' === $options['action']
			&& 'plugin' === $options[ 'type' ]
		) {
			// just clean the cache when new plugin version is installed
			delete_transient( $this->cache_key );
		}

	}
}

new pv_mishaUpdateChecker();